@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of MIDI files
 
-our $VERSION = '0.1500';
+our $VERSION = '0.1501';
 
 use Moo;
 use strictures 2;
@@ -120,13 +120,6 @@ has one_channel => (
 );
 
 
-has bounds => (
-    is      => 'ro',
-    isa     => \&_is_boolean,
-    default => sub { 0 },
-);
-
-
 has score => (
     is       => 'rw',
     init_arg => undef,
@@ -553,7 +546,7 @@ MIDI::Ngram - Find the top repeated note phrases of MIDI files
 
 =head1 VERSION
 
-version 0.1500
+version 0.1501
 
 =head1 SYNOPSIS
 
@@ -563,9 +556,9 @@ version 0.1500
   my $mng = MIDI::Ngram->new(
     in_file      => [ 'eg/twinkle_twinkle.mid' ],
     ngram_size   => 3,
+    max_phrases  => 0, # Analyze all events
     patches      => [qw( 68 69 70 71 72 73 )],
     random_patch => 1,
-    bounds       => 1,
   );
 
   $mng->process;
@@ -629,7 +622,8 @@ during audio playback.
 
 =head2 patches
 
-The patches to choose from (at random) if given the B<random_patch> option.
+The patches to choose from (at random) if given the B<random_patch>
+option.
 
 Default: C<[0 .. 127]>
 
@@ -691,12 +685,6 @@ Boolean.  Accumulate phrases onto a single channel.
 
 Default: C<0>
 
-=head2 bounds
-
-Boolean.  Include pitch range in the analysis.
-
-Default: C<0>
-
 =head2 score
 
 The score object in L<MIDI::Simple/"MAIN-ROUTINES">.  Constructed by
